#
# spec file for package gsequencer
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libagssonumber 7
%define libgsequencersonumber 0
# The condition is run functional tests; defaulted off and needs to be
# activated with --with run_functional_tests command line switch.
%bcond_with run_functional_tests
Name:           gsequencer
Version:        7.2.4
Release:        1.5
Summary:        Audio processing engine
License:        AGPL-3.0-or-later AND GPL-3.0-or-later AND GFDL-1.3-only
Group:          Productivity/Multimedia/Sound/Midi
URL:            https://nongnu.org/gsequencer
Source0:        https://download.savannah.gnu.org/releases/gsequencer/7.2.x/%{name}-%{version}.tar.gz
# improve glib-2.0 compatibility to version 2.54
Patch1:         gsequencer.1-improved-glib-compatibility.patch
BuildRequires:  gcc-c++
BuildRequires:  cunit-devel
BuildRequires:  fop
BuildRequires:  texlive-latex
BuildRequires:  texlive-fancybox
BuildRequires:  texlive-collection-fontsrecommended
BuildRequires:  texlive-jknapltx
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  dssi-devel
BuildRequires:  fluid-soundfont-gm
BuildRequires:  gettext-devel >= 0.19.8
BuildRequires:  gstreamer-plugins-base
BuildRequires:  gstreamer-plugins-good
BuildRequires:  gtk-doc
BuildRequires:  gtk-doc-mkpdf
BuildRequires:  hydrogen
BuildRequires:  ladspa-cmt
BuildRequires:  ladspa-devel
BuildRequires:  libtool
BuildRequires:  lv2-devel
BuildRequires:  lv2-swh-plugins
BuildRequires:  pkgconfig
BuildRequires:  pulseaudio
BuildRequires:  xvfb-run
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libinstpatch-1.0)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(uuid)

%description
Advanced Gtk+ Sequencer is an audio
sequencer application supporting the LADPSA, DSSI and Lv2 plugin
formats. It can output to Pulseaudio server, JACK and ALSA.

You may add multiple sinks, mix different sources by producing
sound with different sequencers. Furthermore, it features a pattern
and piano roll and there is an editor to automate ports.

%prep
%autosetup -p0

%build
autoreconf -fi
export LIBAGS_CPPFLAGS='-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security'
export LIBAGS_THREAD_CPPFLAGS='-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security'
export LIBAGS_SERVER_CPPFLAGS='-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security'
#export LIBAGS_VST3_RELEASE_TYPE="-DRELEASE"
#export LIBAGS_VST3_CPPFLAGS='-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security'
#export LIBAGS_VST3_CXXFLAGS="-I/usr/include/vst3sdk"
#export LIBAGS_VST3_LIBS="-L/usr/%{_lib}/vst3sdk"
export LIBAGS_AUDIO_CPPFLAGS='-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security'
export LIBAGS_GUI_CPPFLAGS='-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security'
export LIBGSEQUENCER_CPPFLAGS='-DAGS_CSS_FILENAME=\"'%{_datadir}'/gsequencer/styles/ags.css\" -DAGS_ANIMATION_FILENAME=\"'%{_datadir}'/gsequencer/images/gsequencer-800x450.png\" -DAGS_LOGO_FILENAME=\"'%{_datadir}'/gsequencer/images/ags.png\" -DAGS_LICENSE_FILENAME=\"'%{_datadir}'/licenses/gsequencer/COPYING\" -DAGS_ONLINE_HELP_A4_PDF_FILENAME=\"'%{_docdir}'/gsequencer/pdf/user-manual-a4.pdf\" -DAGS_ONLINE_HELP_LETTER_PDF_FILENAME=\"'%{_docdir}'/gsequencer/pdf/user-manual-letter.pdf\" -DAGS_REDUCE_RT_EVENTS=1 -DAGS_LIBRARY_SUFFIX=\".so\" -D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security'
#NOTE:JK: no --enable-vst3 passed to configure
%configure \
%if %{with run_functional_tests}
    --enable-run-functional-tests \
%endif
    FO_XSL=/usr/share/xml/docbook/stylesheet/nwalsh/current/fo/docbook.xsl HTMLHELP_XSL="/usr/share/xml/docbook/stylesheet/nwalsh/current/htmlhelp/htmlhelp.xsl" --disable-upstream-gtk-doc --enable-introspection --disable-oss --with-poppler --with-gtk-unix-print --enable-gtk-doc --enable-gtk-doc-html

%make_build all
%make_build html
%make_build fix-local-html
%make_build pdf

%install
%make_install
%make_install install-compress-changelog
%make_install install-html-mkdir
%make_install install-html-mkdir-links
%make_install install-html
%make_install install-pdf-mkdir
%make_install install-pdf
find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_datadir}/doc-base/
mkdir -p %{buildroot}%{_datadir}/doc/packages
mv %{buildroot}%{_datadir}/doc/gsequencer  %{buildroot}%{_docdir}
%find_lang %name

%check
xvfb-run --server-args="-screen 0 1920x1080x24" -a make check
desktop-file-validate %{buildroot}/%{_datadir}/applications/gsequencer.desktop

%files -f %name.lang
%license COPYING
%{_bindir}/gsequencer
%{_bindir}/midi2xml
%{_mandir}/man1/gsequencer.1*
%{_mandir}/man1/midi2xml.1*
%{_datadir}/gsequencer/
%{_datadir}/xml/gsequencer/
%{_docdir}/gsequencer/
%{_docdir}/gsequencer/pdf/user-manual-a4.pdf
%{_docdir}/gsequencer/pdf/user-manual-letter.pdf
%{_datadir}/applications/gsequencer.desktop
%{_datadir}/icons/hicolor/*/apps/gsequencer.png
%{_datadir}/icons/hicolor/scalable/apps/gsequencer.svg
%{_datadir}/metainfo/*
%{_datadir}/mime/packages/*

%package -n libags%{libagssonumber}
Summary:        GSequencer core libraries
Group:          System/Libraries

%description -n libags%{libagssonumber}
Advanced Gtk+ Sequencer is an audio sequencer application.
This subpackage contains part of its library set.

%package -n typelib-1_0-Libags-7_0
Summary:        Introspection bindings for GSequencer's core libraries
Group:          System/Libraries

%description -n typelib-1_0-Libags-7_0
Advanced Gtk+ Sequencer is an audio sequencer application.
This package provides the GObject Introspection bindings for Libags.

%package -n libgsequencer%{libgsequencersonumber}
Summary:        GSequencer core libraries
Group:          System/Libraries

%description -n libgsequencer%{libgsequencersonumber}
Advanced Gtk+ Sequencer is an audio sequencer application.
This subpackage contains part of its library set.

%package devel
Summary:        Advanced Gtk+ Sequencer library development files
Group:          Development/Libraries/C and C++
Requires:       libags%{libagssonumber} = %{version}
Requires:       libgsequencer%{libgsequencersonumber} = %{version}

%description devel
Advanced Gtk+ Sequencer library development files.

%files devel
%{_includedir}/ags/
%{_libdir}/libags.so
%{_libdir}/libags_thread.so
%{_libdir}/libags_server.so
%{_libdir}/libags_gui.so
#%{_libdir}/libags_vst.so
%{_libdir}/libags_audio.so
%{_libdir}/libgsequencer.so
%{_datadir}/gir-1.0/*.gir
%{_libdir}/pkgconfig/libags.pc
%{_libdir}/pkgconfig/libags_audio.pc
%{_libdir}/pkgconfig/libags_gui.pc
%{_libdir}/pkgconfig/libgsequencer.pc

%package -n gsequencer-devel-doc
Summary:        Documentation for Advanced Gtk+ Sequencer
Group:          Documentation/HTML
BuildArch:      noarch

%description -n gsequencer-devel-doc
Advanced Gtk+ Sequencer library development documentation.

%post   -n libags%{libagssonumber} -p /sbin/ldconfig
%postun -n libags%{libagssonumber} -p /sbin/ldconfig
%post   -n libgsequencer%{libgsequencersonumber} -p /sbin/ldconfig
%postun -n libgsequencer%{libgsequencersonumber} -p /sbin/ldconfig

%files -n libags%{libagssonumber}
%{_libdir}/libags.so.%{libagssonumber}*
%{_libdir}/libags_thread.so.%{libagssonumber}*
%{_libdir}/libags_server.so.%{libagssonumber}*
%{_libdir}/libags_gui.so.%{libagssonumber}*
#%{_libdir}/libags_vst.so.%{libagssonumber}*
%{_libdir}/libags_audio.so.%{libagssonumber}*

%files -n typelib-1_0-Libags-7_0
%{_libdir}/girepository-1.0/Ags-7.0.typelib
%{_libdir}/girepository-1.0/AgsGui-7.0.typelib
%{_libdir}/girepository-1.0/AgsAudio-7.0.typelib

%files -n libgsequencer%{libgsequencersonumber}
%{_libdir}/libgsequencer.so.%{libgsequencersonumber}*

%files -n gsequencer-devel-doc
%{_datadir}/gtk-doc/
%{_datadir}/doc/libags-audio-doc/

%changelog
* Sun Nov 10 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v7.2.4 fixed potential SIGSEGV because of
  buffer-overflow in ags_sfz_synth_util.c.
- improved selection in notation, automation and wave editor.
* Sat Oct 26 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v7.0.8 fixed missing keyboard input of AgsSyncsynth,
  AgsFMSyncsynth, AgsFFPlayer and AgsPitchSampler.
- fixed broken unit test
- minor improvements
* Fri Oct 25 2024 Joël Krähemann <jkraehemann@gmail.com>
- new major release version 7.0.6 fixed MIDI version 2 support,
  prior had wrong byte order.
- implemented ags_midi_ci_util_is_*() functions to test for
  specific MIDI-CI message.
- implemented ags-fx-notation MIDI version 2 support.
- implemented MIDI 1 and 2 control change parsing functions as
  ags_recall_midi[1-2]_control_change().
* Sun Oct 13 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.16.22 minor improvements and fixed potential
  SIGSEGV while shrinking notation, automation and wave form data.
* Wed Aug 21 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.16.18 minor improvements.
* Fri Jul 26 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.16.16 minor improvements and bug-fixes.
* Sun May 19 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.13.4 fixed recently broken scrollbars.
- new since v6.13.3 fixed potential SIGSEGV and improved UI.
- improved dark mode
* Sun May 12 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.12.1 much UI cosmetics and minor improvements.
* Fri May  3 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.10.1 fixed tempo and a lot of cosmetics in UI.
- refactored widgets in libgsequencer.so to use GtkWindow as parent
  class instead of GtkDialog.
* Thu Apr 25 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.9.0 fixed note 256th counter bug.
- refactored all soundcard implementations to use new utility
  functions.
* Thu Apr 18 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.8.3 many bug-fixes.
- fixed auto-scroll.
- fixed memory-leak while stop playback.
- fixed ags-fx-dssi.
- fixed SIGSEGV with remove automation port.
- new in version 6.6.0 implemented AgsFileDialog and AgsFileWidget.
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Sat Feb 17 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.5.2 updated screenshots in user manual docs.
- fixed composite toolbar tool dialogs.
* Tue Feb  6 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.4.3 enabled auto-scroll and refactored update-ui
  event.
* Sat Jan 27 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstram v6.3.5 fixed some compiler warnings and make it
  compile with clang.
* Sun Jan 14 2024 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.3.1 improved 256th note processing in the audio
  engine.
- fixed potential SIGSEGV with composite editor
- fixed potential SIGSEGV with AgsSF2Synth and AgsSFZSynth
* Sat Oct  7 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.1.3 support of 256th note x offset support in
  audio engine and piano roll.
* Sat Sep 23 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.0.13 fixed resampling of ags-fx-buffer and
  ags-fx-playback.
- minor improvements.
* Mon Sep 11 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.0.11 fixed memory leaks.
* Sun Sep  3 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.0.8 fixed silent pads.
* Tue Aug 22 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v6.0.1 implemented MIDI UMP utility functions.
- refactored ags_midi_smf_util.[ch]
- refactored ags_midi_util.[ch]
- refactored ags_osc_buffer_util.[ch]
* Thu Aug 10 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v5.5.3 improved resampling. Implemented MIDI CI
  version 1.2 util.
* Fri Aug  4 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v5.4.3 minor improvements
* Sat Jul  1 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v5.4.0 improved automation editor.
* Sat Jun 24 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v5.3.12 more fixes to automation editor.
- updated some screenshots in the manual
- minor improvements
* Fri Jun 16 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v5.3.8 improved automation editor and ramp
  acceleration dialog.
- minor improvements.
* Sat Jun  3 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v5.2.5 mega update with improvements, bug-fixes and
  new features.
- AgsSF2Synth additional effect tremolo, vibrato and wah-wah
- AgsSFZSynth additional effect tremolo, vibrato and wah-wah
- fixed and improved ags-fx-lv2 effect processor
- added json-glib-1.0 dependency
- fixed MIDI input
* Sun May 14 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v5.1.4 improved conditional build
- implemented tempo editor
* Sun Apr 16 2023 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v4.5.5 introduced api-pdf automake target
- new since v4.5.4 fixed AgsSFZSynth by correcting type check.
* Sat Sep 17 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v4.4.1 fixed potential SIGSEGV while adjusting
  buffer size and using AgsSF2Synth.
- fixed premature stop of playback after audio export.
* Sat Jul 23 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v4.2.13 fixed don't initialize playback recall
  twice.
- minor improvements
* Fri Jul  1 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v4.2.10 minor improvements and some bug-fixes.
* Sun Jun 12 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v4.2.3 implemented refresh port and no-update while
  refreshing ports.
* Sun Jun  5 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v4.2.0 improved API reference manual, added more
  descriptions.
- implemented getter/setter of AgsAudioFile.
- since 4.1.0 implemented preset editor.
* Thu May 26 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v4.0.8 fixed machine's input dialogs and machine
  selector popover.
- fixed unitialized value in ags_simple_file.c.
- minor improvements.
* Tue May 24 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v4.0.4 major API improvements.
- migrated to libgtk-4.0
- migrated to libsoup-3.0
- updated gsequencer.spec version identifier
* Mon Apr 25 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.19.0 fixed potential SIGSEGV with
  AgsExportWindow.
- Show PDF handbook instead of HTML in gsequencer.
- New dependency poppler-glib.
- Removed dependency webkit2gtk-4.0.
* Tue Feb 22 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.18.2 implemented AgsMetaDataWindow and hamburger
  menus.
- new since 3.18.0 implemented support for GtkApplication and open
  files attach to existing process. Note, there is a command line
  option to prevent this.
* Sun Feb 13 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.17.5 updated user's handbook manual and minor
  improvements.
* Thu Feb 10 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.17.3 minor improvements.
* Sun Feb  6 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.17.1 implemented AgsSFZSynth and ags-fx-sfz-synth
  effect processor.
- implemented additional getter/setter functions of AgsSFZFile,
  AgsSFZGroup, AgsSFZRegion and AgsSFZSample.
* Sun Jan 30 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.16.14 fixed potential SIGSEGV because of
  unitialized AgsApplySF2MidiLocale field synth.
- minor improvements.
* Sat Jan 22 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.16.12 implemented --no-config command line option
  to bypass config read from XML.
- new environment variables AGS_CONFIG and AGS_TEST_CONFIG to
  inject arbitrary config file.
- minor improvements and bug fixes.
* Sun Jan 16 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.16.6 fixed AgsSF2Synth missing program and
  resample.
- new since 3.16.5 fixed AgsFFPlayer restore from XML.
- minor improvements and fixes.
* Fri Jan 14 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.16.2 minor improvements.
- new since 3.16.1 implemented AgsSF2Synth allowing you to play
  Soundfont2 files by MIDI locale i.e. select bank and program.
- minor improvements.
* Sat Jan  8 2022 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.15.3 fixed AgsSynthUtil and AgsFMSynthUtil.
- new since 3.15.2 fixed configure events of editor
  implementations.
- new since 3.15.0 implemented AgsHybridFMSynth.
- implemented AgsNoiseUtil.
- minor improvements.
* Mon Dec 27 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.14.10 fixed notation, automation and wave lists
  to do not allow duplicates.
- fixed corrupted selection with duplicates.
- minor improvements.
* Mon Dec 27 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.14.9 fixed wave form editor selection.
- new since 3.14.7 fixed wave form editor cursor, enabling you
  to proper copy & paste within it.
- new since 3.14.6 fixed missing filename restore from XML of
  AgsAudiorec.
- fixed ALSA and OSSv4 export thread.
- fixed missing start of AgsAudiorec while export.
- minor improvements.
* Wed Dec 22 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.14.5 fixed automation editor to respect toggled
  and integer ports and apply lower correct.
* Tue Dec 21 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.14.3 implemented AgsHybridSynth powered by new
  ags-fx-synth effect processor.
- implemented ags-fx-chorus.
- implemented enabled port of ags-fx-low-pass and ags-fx-high-pass.
- minor improvements.
* Mon Dec 13 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.13.7 fixed dependent code of refactored objects
  OSSv4 and ALSA device IO.
- new since 3.13.4 implemented AgsChorusUtil.
* Thu Dec  9 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.13.3 fixed SIGABRT during termination of
  GSequencer.
- implemented AgsAlsaDevout, AgsAlsaDevin and AgsAlsaMidiin
- implemented AgsOssDevout, AgsOssDevin and AgsOssMidiin
- deprecated AgsDevout, AgsDevin and AgsMidiin
- fixed wave form editor clipboard
* Wed Dec  1 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.13.0 implemented time stretch utility functions
  and made it available in gsequencer wave form editor.
- extended developer manual.
* Fri Oct 29 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.12.6 improved AgsAnimationWindow to obtain stride
  from format.
- new since 3.12.5 fixed SIGSEGV with AgsRampAccelerationDialog and
  AgsSelectAccelerationDialog.
- implemented missing paste flags of AgsCompositeToolbar.
- implemented missing channel selector toggle of
  AgsCompositeToolbar.
- minor improvements.
* Wed Oct 20 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.12.3 fixed SIGSEGV while destroy AgsMachine and
  while restore from AgsSimpleFile XML.
- fixed functional UI tests.
* Tue Oct 19 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.12.2 implemented AgsCompositeEditor, replacing
  AgsNotationEditor, AgsAutomationEditor and AgsWaveEditor.
- some bug-fixes.
* Wed Sep  1 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.10.15 implemented VST3 host, which is excluded
  from build.
- minor improvements.
* Tue Aug  3 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.9.7 completed refactoring of wanted utility
  functions.
* Fri Jul 30 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.9.5 completed refactoring of ags_synth_util.c
  and ags_fm_synth_util.c.
- added unit-tests.
* Wed Jul 28 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.9.4 fixed some uninitialized values.
- new since v3.9.3 implemented various functions related to
  parse using AgsSolverMatrix, AgsSolverVector and
  AgsSolverPolynomial as well arithmetic functions and elimination
  procedure.
- fixed SIGSEGV of AgsPitchSampler
- added unit tests
- incomplete refactoring of synth utility functions
- new since v3.9.2 implemented ags_volume_util.c,
  ags_envelope_util.c, ags_peak_util.c and ags_resample_util.c
- many now deprecated utility functions, the replacement have got
  a different function signature whereby only a pointer to a struct
  is required containing all required parameters. Further the
  replacement uses accelerated operations are inteded to run just
  in time.
* Mon Jun 28 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.9.1 added empty structs with boxed type for
  utility headers to achieve better organization of introspected
  functions.
* Mon Jun 21 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.9.0 implemented to select different pitch
  functions from UI.
* Sat Jun 12 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.8.13 fixed gtk-doc missing sections.
- new since v3.8.12 improved to pitch by using fluidsynth code.
- implemented new utility functions from fluidsynth.
- updated user's handbook chapter 3 missing hot-keys.
* Mon May 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not own base filesystem directories such as
  /usr/share/mime/packages and /usr/share/metainfo.
* Sun Apr 11 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.8.10 improved ags_hq_pitch_util.c.
- fixed more deprecated Gtk+-3.0 symbols.
- minor improvements.
* Fri Apr  2 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.8.5 fixed ags_lfo_synth_util.c offset and
  iteration.
- fixed potential SIGSEGV while clicking AgsPiano of
  AgsNotationEditor.
* Thu Apr  1 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.8.4 fixed empty keys while using no tuning in
  ags_hq_pitch_util.c
- improved iteration of AgsChannel in ags_fx_factory.c
* Wed Mar 31 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.8.3 fixed missing XML IO of new available
  controls.
- new since v3.8.2 fixed gtk-doc missing sections.
- new since v3.8.1 additional volume controls to AgsSyncsynth,
  AgsFMSyncsynth and AgsMatrix.
- new since v3.8.0 fixed many deprecated Gtk+-3.0 symbols.
  Additional volume controls to AgsFFPlayer and AgsPitchSampler.
- minor improvements
* Wed Mar 17 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.7.50 fixed missing initial loop information after
  AgsMachine::map-recall() signal callback to ags-fx-playback and
  ags-fx-notation.
* Sat Mar 13 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.7.48 updated user's handbook chapter 2 Docbook
  XML file.
- new since v3.7.44 fixed potential SIGSEGV with AgsPluginBrowser
  no plugin selected.
- new since v3.7.43 Polish translation.
* Sun Feb 21 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.7.42 run tests with valgrind and fixed some bugs
  shown.
- implemented ags_notation_to_raw_midi() and
  ags_notation_from_raw_midi().
- improved AgsServer response.
- fixed ref-count of AgsAudioApplicationContext and
  AgsXorgApplicationContext.
- fixed uninitialized buffer of AgsFxPeakChannel
- fixed AgsOscConnection and AgsOscClient uninitialized, leaked
  and use after free errors.
- fixed ref-count of ags_recycling_position()
- fixed .pc files
- minor improvements.
* Tue Feb  9 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.7.35 fixed bad bug related to serialization of
  AgsComplex and other float types. This affects ags-fx-envelope
  to do wrong behavior.
- since v3.7.34 correct double _Complex types for all AgsComplex.
- since v3.7.32 improved thread-safety of pulseaudio
- since v3.7.31 minor improvements
* Mon Jan 25 2021 Joël Krähemann <jkraehemann@gmail.com>
- added ${datadir}/locale/*/LC_MESSAGES/gsequencer.mo to gsequencer
  in specs file.
- new upstream v3.7.30 fixed use ags-fx instead of deprecated
  recalls in ags_simple_file.c while restore.
- fixed wrong cast with interface in ags_xorg_application_context.c
- new since 3.7.29 fixed AgsThread fields start_mutex and
  start_cond type.
- new since 3.7.26 fixed missing initialization of ::read() and
  ::write() of AgsApplicationContextClass.
- implemented some get_type() functions of enums.
- other improvements and fixes.
- new since 3.7.24 added French translation
- new since 3.7.23 added German translation
* Sun Jan  3 2021 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.7.22 fixed AgsTurtle access after freeing string.
- new since v3.7.20 fixed some reference count and minor
  improvements.
- improved developer's manual with a listing about
  ags_fx_factory_create()
- additional unit-tests
* Tue Dec 22 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.7.17 fixed string pointer comparision.
* Tue Dec 22 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.7.16 fixed might be unitialized in ags_audio.c
  with older gcc versions.
* Mon Dec 21 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.7.15 improved htmlhelp to have navigation and
  custom css.
- new since v3.7.9 deprecated ags/audio/recall/* and
  ags/audio/ags_recall_{ladspa,dssi,lv2}*, because replaced by
  ags/audio/fx/*.
- minor improvements and fixes.
* Mon Dec  7 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.7.6 fixed meson build and functional integration
  tests.
- new since v3.7.4 implemented ags-fx recalls on AgsOutput,
  extended ags_fx_factory.c to respect sound behviour flags chained
  to output or input.
- improved ags_soundcard_util_adjust_delay_and_attack() to correct
  attack within AGS_SOUNDCARD_DEFAULT_PERIOD.
- new since v3.7.3 changed base key to lower of AgsFFPlayer and
  AgsPitchSampler.
- improved Soundfont2 support to select nearest sample.
- improved SFZ support.
* Thu Dec  3 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.7.1 fixed pitch loudness by adjusting volume.
* Wed Nov 25 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.6.22 improved notation, automation and wave
  editor to do proper GUI scale.
- new since v3.6.17 fixed AgsEnvelopeDialog and ags-fx-envelope
  recall.
- implemented additional getter/setter functions.
- added unit-tests.
- minor improvements.
* Mon Nov  9 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.6.14 fixed AgsPlayback cleanup.
* Mon Nov  9 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.6.13 fixed double free as accessing fx recalls
  of Ags*DssiBridge and Ags*Lv2Bridge.
- new functional tests and a new parallel integration tests make
  target.
* Thu Nov  5 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.6.7 fixed more pthread remains, caused a SIGSEGV
  while opening SF2 or SFZ files.
* Tue Nov  3 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.6.6.
- added some getter/setter functions to AgsPiano, to set either
  vertical or horizontal layout and to set mouse button state.
- minor improvements, fixed non generic code with mixed GtkWidget
  and AgsLineMember implementation of GtkContainer's children.
* Sat Oct 31 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.6.3 removed pthread remains.
- since 3.6.2 implemented ags_fast_pitch_util.[ch] and use it in
  ags_sf2_synth_util.c and ags_sfz_synth_util.c.
- implemented more get_type() functions of enum values.
* Sun Oct 25 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.6.1 implemented gstreamer file IO, read/write
  mp3, mp4, mkv, webm ...
- updated gtk-doc.
- implemented some get type functions of enums.
- edited spec file and added gstreamer dependencies.
* Thu Oct  8 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.5.16 fixed missing AgsMutable interface
  implementation of ags-fx-volume.
- fixed missing update of LV2_Options_Option after configuration
  changed.
- fixed initial loop set of specific machines.
* Fri Sep 18 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.5.12 fixed missing reset of notation edit's
  horizontal scrollbar after zoom changed.
- fixed shrinking audio channels.
- implemented find plugins using fallback to alternate search path.
* Sun Sep 13 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.5.9 fixed a problem with tempo. Wrong calculation
  of delay between notes in ags_soundcard_util.c
* Mon Jul 20 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.5.6 fixed missing $(docdir)/images/adwaita.
- fixed since v3.5.5 memory leak causing performance impact and
  AgsFMSyncsynth missing restore of loop fields in
  ags_simple_file.c.
* Thu Jul 16 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.5.3 minor improvements.
* Thu Jul 16 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.5.2 fixed missing expand of WebView.
* Thu Jul 16 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.5.1 small release with improved user experience
  during quit. Asking to do a fast export of AgsAudiorec.
- Improved online help allowing you to go home, previous or forward
  page of PDF user manual.
- Added PDF support using poppler and cairo as a alternative to
  webkit2gtk-4.0 in online help window.
* Sun Jul  5 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.4.11 improved AgsSF2SynthGenerator and
  AgsSFZSynthGenerator to be faster.
- improved thread safety.
- minor improvements.
* Sun Jun 28 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.4.9 compute phase using fmod() in
  ags_filter_util.c
* Wed Jun 24 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.4.6 fixed sscanf call with wrong signed integer
  in ags_sfz_synth_util.c
- fixed not intialized sound_scope in ags_audio_loop.c
- minor improvements
* Tue Jun 23 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.4.5 improved ags_filter_util.c to use projection
  during 2nd pitch rewrite.
* Sun Jun 21 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.4.4 improved ags_audio_buffer_util.c copy
  AgsComplex and fixed potential SIGSEGV because of buffer-overflow
* Sun Jun 21 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.4.3 fixed missing include in
  ags_xml_authentication.c
- new since v3.4.0 SF2 and SFZ synth generator able to pitch
  missing samples.
* Fri Jun 12 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.3.16 fixed ags-fx-ladspa and ags-fx-lv2.
* Tue Jun  9 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.3.14 improved automation editor if specifier is
  NULL.
- added ags-fx-volume to AgsPanel.
* Tue Jun  9 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.3.13 fixed missing automation port of
  ags-fx-volume.
* Sat Jun  6 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.3.12 fixed missing include string.h in
  ags_math_util.c.
* Thu Jun  4 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.3.11 more fixes to AgsAudiorec.
- provide patch gsequencer.1-improved-glib-compatibility.patch to
  improve compatibility to glib-2.0 version 2.54.
* Sat May 30 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.3.9 fixed AgsAudiorec's new ags-fx-playback
  recall to play and record audio data.
* Tue May 26 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.3.7 fixed potential SIGSEG in AgsSpectrometer as
  modifying buffer-size and improved MIDI playback.
- fixed missing includes.
- minor bug-fixes.
* Tue May 19 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.3.3 fixed pointer corruption in ags-fx-peak.
- fixed missing return value of ags_fx_factory_create(). This lets
  you modify bulk member ports, now.
- fixed reverse mapping of DSSI and LV2 plugins.
* Mon May 18 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.3.1 implemented ags-fx engine to replace
  ags/audio/recall, see ags/audio/fx.
- many bug-fixes, like out-of-sync with UI, wrong channel mapping
- improved restore from AgsSimpleFile
- refactored ags_menu_action_callbacks.c and ags_simple_file.c to
  use new ags/X/ags_machine_util.c
* Thu Apr 16 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.2.15 improved AgsDial of AgsEffectBulk,
  AgsEffectLine and AgsLine to apply page-size of adjustments.
- improved AgsTurtle to check against unichar ranges.
- improved AgsNotationEditor to queue resize.
- other improvements.
* Wed Apr 15 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.2.14 fixed potential NULL pointer dereference and
  wrong midi-end-mapping of AgsSimpleFile.
* Mon Apr 13 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.2.13 refactored and extended AgsTurtle, fixed
  greedy ags-lv2 and ags-dssi recall.
* Fri Apr 10 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.2.10 improved AgsMachineEditor to create plugin
  dialog only as needed. Causes faster launch of the dialog.
* Wed Apr  8 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.2.8 implemented AgsLv2TurtleScanner quick scan.
- updated API Reference Manual.
- minor improvements.
* Tue Mar 31 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.2.4 reverted dependency to GLib version 2.56.0
- implemented additional getter/setter functions of properties.
- refactored some objects to use properties for setter functions.
- disabled GMainLoop integration of AgsTaskLauncher in
  AgsAudioApplicationContext.
* Fri Mar 13 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.2.0 disabled GMainLoop integration of
  AgsTaskLauncher in AgsXorgApplicationContext, giving better
  performance.
- implemented many getter/setter functions of properties.
- updated developer docs.
- minor improvements.
* Thu Feb  6 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.1.2 fixed 64bit-portability-issue reported by
  previous build on Leap 15.2.
* Wed Feb  5 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.1.1 implemented meta widgets of notation,
  automation and wave editor.
- implemented getter/setter functions of many properties.
- implemented acoustic feedback of DSSI and LV2 recall.
- fixed missing ref-count of AgsRecallDssi:count-beats-audio-run.
- fixed automation editor not showing again after machine changed.
- edited spec file to use --disabled-upstream-gtk-doc which causes
  the makefile to install into standard directories.
* Fri Jan 17 2020 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v3.0.4 migrated to Gtk3, added GObject-Introspection
  annotations and implemented AgsServer.
- edited spec file to deal with improved Makefile.am, additional
  dependencies and to install gir and typelib files.
- dropped gsequencer.0-fix-makefile-am.patch
* Fri Dec 27 2019 Joël Krähemann <jkraehemann@gmail.com>
- improved performance
* Fri Dec 27 2019 Joël Krähemann <jkraehemann@gmail.com>
- implemented ags_audio_buffer_util_resample_with_buffer() and
  related
- fixed potential buffer-overflow in ags_sfz_sample.c
- fixed SIGSEGV in ags_sound_resource.c
* Tue Dec 17 2019 Joël Krähemann <jkraehemann@gmail.com>
- fixed potential SIGSEGV as adding AgsBulkMember to AgsFFPlayer.
- fixed accessing freed memory in ags_effect_bridge.c
* Thu Nov 28 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.4.1 imroved idle CPU usage
- implemented audible feedback of AgsPiano
* Mon Oct 28 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.3.15 improved ags_sound_resource_read_wave() to
  deal with different samplerates.
* Sun Oct 13 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.3.13 minor bug-fixes.
- fixed persisting SFZ files of AgsPitchSampler.
* Thu Oct  3 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.3.8 minor bug-fixes.
- updated gsequencer.0-fix-makefile-am.patch
* Tue Sep 10 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.3.3 fixed missing includes.
* Tue Sep 10 2019 Joël Krähemann <jkraehemann@gmail.com>
- fixed ags_fourier_transform_util_test.c
* Tue Sep 10 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.3.1 new machines AgsFMSynth, AgsFMSyncsynth and
  AgsPitchSampler.
- Support for complex data type as audio buffer.
- SFZ file format support.
- Extended the libags-audio API.
* Sun Aug 11 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.36 optimized iterating in
  ags_audio_buffer_util.c.
- reverted lock-free audio buffer because it causes distorted
  audio.
* Thu Aug  8 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.35 fixed libxml2 related memory-leaks and minor
  improvements.
* Tue Jul 30 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.30 make compile using gcc-9.
* Mon Jul 29 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.29 fixed missing return type.
* Mon Jul 29 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.28 fixed ags_audio_buffer_util_peak_*() to
  handle 0.0 correct.
- fixed dead-lock related to pulseaudio and new lock-free soundcard
  buffer.
- improved AgsSimpleFile to round audio loop start/end of
  AgsSyncsynth during writing XML.
* Sat Jul 27 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.27 removed unneeded mutexes during refactoring.
- new since v2.2.26 implemented lock-free soundcard buffer.
- new since v2.2.25 implemented vector optimization of
  ags_audio_buffer_util.c
- fixed in v2.2.24 SIGSEGV during open file.
* Mon Jul 22 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.23 replaced hard-coded font names.
- fixed timing issue with relative counters.
* Fri Jul 19 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.22 implemented gui-scale configuration key,
  allowing you to adjust the size of various widgets.
- various improvements to Gtk+-2.0 widgets provided by
  libags_gui.so.
- minor bug-fixes.
* Sat Jul 13 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.19 refactored AgsLv2Bridge and
  AgsLiveLv2Bridge.
- improved detecting LV2 instrument as parsing names.
- minor improvements.
* Tue Jul  9 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.17 fixed race-condition ending in a dead-lock
  in view of new sync counter introduced in 2.2.10.
* Fri Jul  5 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.10 providing a new sync counter to AgsMainLoop
  interface, resulting in less synchronization overhead.
* Wed Jul  3 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.9 improved LV2 logarithmic ports.
* Sat Jun 29 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstreamv v2.2.7 improved check lv2 plugin port duplicate.
* Tue Jun 25 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.2.5 reworked LV2 RDF Turtle parser. It is fast!
* Mon Jun 17 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.77 fixed potential SIGSEGV in ags_simple_file.c
  as XPath evaluates to NULL. This pointer was dereferenced.
* Wed Jun 12 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.76 improved ags_soundcard_editor_reset() to
  apply backend properly.
- improved various mutices.
- improved running integration tests, there is a new configure
  switch available.
- fixed developer's book deprecated symbols.
* Sun Jun  2 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.74 fixed potential SIGSEGV during restore from
  XML file.
- fixed potential SIGSEGV in ags_synth_generator.c.
- fixed some memory-leaks.
* Sun May 19 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.72 fixed OSC meter controller potential
  SIGSEGV.
- implemented OSC meter monitoring refresh-rate configuration
  option.
- minor improvements to the documentation.
* Fri Apr 12 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.69 fixed modifying bank port of AgsDrum and
  AgsMatrix.
- fixed non thread-safe get type functions in ags/audio/thread.
- fixed missing creation of AgsFileLink as growing channels in
  ags_audio_open_audio_file_as_channel().
* Sun Mar 17 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.68 fixed missing unset of
  AGS_SOUND_BEHAVIOUR_REVERSE_MAPPING during restored.
* Sat Mar 16 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.67 fixed 64 bit issue of ags-copy-pattern and
  ags-play-notation recall.
- fixed wrong argument to g_object_unref() in ags_start_sequencer.c
* Wed Mar  6 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.66 API reference manual improvements. Better
  structure of libags_audio.xml and libgsequencer.xml.
* Fri Mar  1 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.64 unified reference count of return values
  from various functions. Minor improvements and fixed memory leak.
* Sun Feb 24 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.61 fixed 2 memory leaks and improved ref
  counting. Tested all machines doing playback. Thus figured out
  and fixed a problem with AgsMatrix.
- Minor improvements.
* Tue Feb 19 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.58 fixed hide bulk member from line member
  editor and automation get current value.
* Sat Feb 16 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.57 using ALSA hints to configure soundcard or
  midi device. Fixed memory leak and potential SIGSEGV. Minor
  improvements.
* Wed Feb 13 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.55 LV2 improvements loading UI and presets.
* Wed Feb 13 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.54 improved MIDI instrument playback and fixed
  faulty property AgsThread:max-precision.
* Mon Feb 11 2019 Joël Krähemann <jkraehemann@gmail.com>
- dropped patch ags-function-test-util-self.patch because rejected
  by upstream. The patch actually fixes old not anymore reachable
  code. Further in GSequencer we use pointers to pthread_t.
* Mon Feb 11 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.52 minor bug-fixes, including fix to broken
  XPath parsing LV2 UI iriref.
* Sun Feb 10 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.51 improved AgsNotation, AgsAutomation and
  AgsWave to do bisect.
- reworked all properties to do correct reference count on GList
  containing objects.
- fixed missing g_object_unref() after g_object_get().
* Mon Feb  4 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.45 fixed memory-leak of AgsOscResponse in
  AgsOscMeterController.
* Sun Feb  3 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.43 fixed ref-count in unit-test
  ags_xorg_application_context_test.c.
* Sun Feb  3 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.42 fixed potential SIGSEGV during set buffer
  size or samplerate of AgsWave or AgsAudioSignal.
* Sat Feb  2 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.41 minor fixes.
* Mon Jan 21 2019 schwab@suse.de
- ags-function-test-util-self.patch: fix type mismatch in test framework
* Sat Jan 19 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.30 fixed resample/reallocate only as needed.
- Disabled functional tests by default. Re-enable during build by
  calling `osc build --with=run_functional_tests`.
* Sat Jan 19 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.39 refactored ags_wave_find_point() doing
  bisect, now.
- Additional makefile to run unit-tests against installed system.
* Thu Jan 17 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.37 fixed missing remove of generic message
  timeout related to AgsMachine implementations.
* Wed Jan 16 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.36 fixed resampling issues on samplerate chage.
- fixed initial seek of AgsAudiorec
- added missing AgsSeekable interface to AgsCaptureWaveChannelRun.
* Mon Jan 14 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.35 minor improvements like updating
  AgsOscillator of AgsSynth and AgsSyncsynth as adjusting
  samlerate.
- fixed adjust loop information according to samplerate as open a
  sound resource.
* Tue Jan  8 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.33 introducing cache configuration option,
  targeting pulseaudio latency issues. This is important since you
  can have only one tic per buffer.
* Sun Jan  6 2019 Joël Krähemann <jkraehemann@gmail.com>
- edited spec to add new files of hicolor icon theme, *.appdata.xml
  and mime type information.
* Sun Jan  6 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.32 improved open files and provided
  gsequencer.appdata.xml.
* Sat Jan  5 2019 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.31 added MIME handler. Additional icons for
  hicolor icone theme.
- Minimal OSC server documentation.
- Implemented set start position.
- Improved AgsResizeEditor to use min/max audio channels and
  input/output pads property of AgsAudio.
* Fri Dec 28 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.21 improved unit tests.
* Thu Dec 27 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.20 targeted compiler warnings.
- Fixed potential dead-locks.
- Minor improvements.
* Sun Dec 23 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.18 fixed AgsSeekSoundcard get/set offset
  property.
- Minor fixes and improvements.
- Added new unit-tests.
* Sun Dec 23 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.17 minor fixes.
* Sat Dec 22 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.16 fixed missing write of sync points of
  AgsSimpleFile and potential division by zero in ags_synth_util.c
  causing SIGSEGV.
- Minor improvements.
* Fri Dec 21 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.14 fixed various memory leaks.
- Improved AgsFunctionalDrumTest and AgsFunctionalFFPlayerTest to
  assert if directory exists.
- Fixed editing configuration in place.
* Wed Dec 19 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.12 implemented UI to configure and start/stop
  OSC server.
- Various fixes to OSC client and server code.
- Added ags_functional_osc_server_test.c.
* Sun Dec  9 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.9 fixed threads starting twice in
  ags_functional_audio_test.c
* Sat Dec  8 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.8 fixed
  ags_play_channel_run_master_remap_dependencies() to check if
  AgsRecallID present.
- Added more unit-tests related to OSC code.
- Minor improvements.
* Fri Dec  7 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.7 fixed uninitialized pointer used by AgsMidiin
  and AgsJackMidiin.
- Refactored OSC controllers.
* Sat Dec  1 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.5 minor fixes.
* Sat Dec  1 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.1.3 implemented OSC server and related content
  format utilities.
- Edited spec file to match new server path.
- Implemented configuration in place.
- Increased minor version.
- Removed gsequencer.1-fix-configure-ac.patch because applied
  upstream.
* Sat Oct 27 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.37 implemented missing code of
  AgsIpatchGigReader and AgsIpatchDLS2Reader as well
  ags_char_buffer_util.c. Minor improvements and bug-fixes.
- Edited spec file to run functional tests which are optional, now.
- Added missing ags/config.h in installation include directory.
- Added gsequencer.1-fix-configure-ac.patch because configure
  option was broken.
* Sat Oct 13 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.35 fixed swap parameters passed to
  ags_tactable_change_bpm() of AgsApplyBpm task. Even more
  unit-tests.
* Fri Oct 12 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.34 minor bug-fixes. Many new unit-tests.
* Tue Oct  9 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.33 fixed ags-copy recall. Additional
  unit-tests.
* Tue Oct  9 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.32 added missing ags-eq10 and ags-analyse to
  recall factory. Additional unit and functional tests provided.
* Sat Oct  6 2018 Joël Krähemann <jkraehemann@gmail.com>
- Added BuildRequires fluid-soundfont-gm and hydrogen to spec file
  because the integration tests need it.
* Fri Oct  5 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.30 fixed compiler error.
* Fri Oct  5 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.29 fixe unit test ags_buffer_test_duplicate()
  to do a cast to guint64 as passing AgsBuffer:x property.
* Fri Oct  5 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.28 minor bug fixes. Fixed non-portable types
  in ags_buffer.c and ags_jack_client.c causing potential integer
  overflow.
* Thu Oct  4 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.27 minor bug fixes. Fixed wrong prototypes in
  ags_synth_util.h and added some unit tests.
* Sun Sep 30 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.25 minor bug fixes. Unified to upper-case
  labels and added missing include.
* Fri Sep 28 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.24 minor bug fixes. Removed log fatal mask and
  improved AgsRampAccelerationDialog.
* Tue Sep 25 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.22 minor bug fixes. Fixed ramp automation
  fixed missing entry of wave form editor dialogs in ags.rc. Added
  missing includes in order to satisfy OpenSUSE Leap 15.0 build.
* Sun Sep 23 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.19 minor bug fixes. Fixed timestamp issue in
  ags_notation_editor.c, fixed ags-envelope recall, implemented
  AgsWaveLoader object and other improvements.
* Tue Sep 18 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.12 minor bug fixes. Fixed ags-envelope and
  ags-play-wave recall. More fixes to DSSI and LV2 bridges. Further
  fixed dead-lock in ags_lv2_urid_manager.c.
* Sat Sep 15 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.8 minor bug fixes. Fixed discarded playback and
  capture of AgsWave object. Further, corrected double free and
  freeing unitialized field. As well, threading scope "channel"
  to have set missing ability flags on AgsChannel object.
* Tue Sep 11 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.2 minor bug fixes. Fixed NULL pointer
  dereference and free in ags_pulse_server_connect_client().
* Sun Sep  9 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.1 minor bug fixes.
* Sat Sep  8 2018 Joël Krähemann <jkraehemann@gmail.com>
- new upstream v2.0.0 including new features like recording using
  ALSA or JACK and wave form editor.
- edited gsequencer.spec and increased soname number.
- new dependency fftw3.
* Fri Aug 10 2018 jkraehemann@gmail.com
- new upstream v1.4.35 fixes to automation editor's copy and paste
  and minor fixes.
* Sat Jul  7 2018 jkraehemann@gmail.com
- new upstream v1.4.34 improved thread-safety of all
  ags_*_get_type() functions by using atomic operations and
  improved plugin recalls accessing shared objects.
* Thu Jun 21 2018 jkraehemann@gmail.com
- new upstream v1.4.32 fixed seeking position and improved object
  references.
* Fri May 11 2018 jkraehemann@gmail.com
- new upstream v1.4.31 fixed muted DSSI and possible SIGSEGV as
  relink line after destroyed machine.
* Tue May  8 2018 jkraehemann@gmail.com
- new upstream v1.4.29 fixed missing timestamp check against lower
  bounds in if statement.
* Sun May  6 2018 jkraehemann@gmail.com
- New upstream v1.4.28 fixed selection of notation and automation
  editor. Minor improvements to lv2 and editor clipboard.
* Wed Apr 11 2018 jkraehemann@gmail.com
- New upstream v1.4.25 fixed memory corruption related to writing
  of pointer to struct of different allocation. Exported missing
  symbol of ags_widget_marshal.h and fixed an event doing potential
  infinite loop.
* Mon Mar 26 2018 jkraehemann@gmail.com
- New upstream v1.4.24 minor improvements. Refactored startup
  process and improved thread-safety.
* Sun Mar 11 2018 jkraehemann@gmail.com
- New upstream v1.4.21 reverted the use of GMainLoop for pulseaudio
  because of a race-condition. Faster lv2 plugin loading.
* Sat Feb  3 2018 jkraehemann@gmail.com
- New upstream v1.4.18 fixed step sequencer's clipboard.
* Fri Feb  2 2018 jkraehemann@gmail.com
- New upstream v1.4.17 various fixes to initialization code of
  recalls in ags_channel.c.
- Fixed playback scope and related code in ags_play_channel_run.c.
* Mon Jan 29 2018 jkraehemann@gmail.com
- Removed libpulse-mainloop-glib0 because it is already provided.
* Sun Jan 28 2018 jkraehemann@gmail.com
- New upstream v1.4.15 replaced pa_main_loop_new() by
  pa_glib_main_loop_new().
- Added libpulse-mainloop-glib0 dependency to spec.
* Mon Jan 22 2018 jkraehemann@gmail.com
- New upstream v1.4.14 important fixes to ags_simple_file.c causing
  SIGSEGV during restore of files containing pattern data.
- Implemented rt-safe mode without any dynamic memory allocation
  from audio processing threads during playback.
- Minor-fixes.
* Tue Jan  9 2018 jkraehemann@gmail.com
- new upstream v1.3.6 fixes the most annoying bug ever. The
  "clipping" issue of GtkPaned was solved by a GtkViewport.
* Mon Jan  8 2018 jkraehemann@gmail.com
- new upstream v1.3.5 minor fixes, increased functional test's
  timeout in order to run more reliable on low power systems.
* Mon Jan  8 2018 jkraehemann@gmail.com
- new upstream v1.3.4 fixes to the notation and automation editor.
  It is considered to be important to update. Since unexpected
  behaviour can occur.
* Sat Jan  6 2018 jkraehemann@gmail.com
- new upstream v1.3.3 various bug-fixes including fix of ags.rc
  theme, memory-leaks and buffer-overflow.
* Fri Jan  5 2018 jkraehemann@gmail.com
- new upstream v1.3.1 minor bug-fixes and ags.rc improvements
* Fri Jan  5 2018 jkraehemann@gmail.com
- new upstream v1.3.0 refactored AgsAutomationEditor, make code
  more intuitive and added new widgets.
- Supporting 4 different paste modes, switches are match audio
  channel/line or no-duplicates.
* Sun Dec 24 2017 jkraehemann@gmail.com
- new upstream v1.2.7 refactored big parts of ags_channel.c, make
  code reusable and strip redundant code as well being thread-safe.
* Fri Dec 22 2017 jkraehemann@gmail.com
- added pulseaudio as dependency of tests
* Fri Dec 22 2017 jkraehemann@gmail.com
- new upstream v1.2.5 fixed unitialized pointer
* Thu Dec 21 2017 jkraehemann@gmail.com
- new upstream v1.2.4 minor fixes
* Thu Dec 21 2017 jkraehemann@gmail.com
- new upstream v1.2.3 minor fixes and rollback of 3 functions
- removed gsequencer.1-fix-libgsequencer-xml.patch because applied
  upstream
* Thu Dec 21 2017 jkraehemann@gmail.com
- new upstream v1.2.2 refactored direct callbacks to UI to async
  message delivery.
- extended libags-audio.so.1 API
- provide Patch1 to fix broken libgsequencer API reference manual
* Fri Dec  8 2017 jkraehemann@gmail.com
- new upstream v1.1.6 fixing unitialized pointers of GtkStyle
- removed libgmp-devel dependency because it is not needed
* Sat Nov 25 2017 jkraehemann@gmail.com
- new upstream v1.1.5 providing minor improvements
* Thu Nov  2 2017 jkraehemann@gmail.com
- edited spec to ensure sonumber
* Thu Nov  2 2017 jkraehemann@gmail.com
- added Group to main package
* Wed Oct 18 2017 alarrosa@suse.com
- Define libagssonumber and libgsequencersonumber in the spec file
  so we are sure the library sonumbers match the package names
* Tue Oct 17 2017 jkraehemann@gmail.com
- removed rpath changes in gsequencer.spec
- added minimal comment about opensuse specific Patch0
* Sun Oct 15 2017 jkraehemann@gmail.com
- update to package gsequencer-1.1.4
* Sun Oct  8 2017 jkraehemann@gmail.com
- update to package gsequencer-1.0.4
- update gsequencer.0-makefile-am.patch
* Sat Oct  7 2017 jkraehemann@gmail.com
- update to package gsequencer-1.0.3
- micro fixes
* Sat Oct  7 2017 jkraehemann@gmail.com
- update to package gsequencer-1.0.2
- provide merged patches by gsequencer.0-fix-makefile-am.patch
- removed gsequencer.3-fix-libgsequencer-doc.patch because applied
  upstream
- removed gsequencer.4-fix-return-value.patch because applied
  upstream
- removed gseqeuencer.0-fix-docbook-path.patch because merged
- removed gsequencer.1-fix-libgsequencer-blue-print.patch because
  merged
- removed gsequencer.2-fix-gtk-doc.patch because merged
* Fri Oct  6 2017 jengelh@inai.de
- Implement shared library guideline.
  Remove duplicate wording in descriptions.
* Mon Oct  2 2017 jkraehemann@gmail.com
- update to package gsequencer-1.0.0
  * Providing fixed LV2UI support. Set default value of controls,
    sync gsequencer provided plugin UI with plugin's own UI. Proper
    destruction of plugin UI by idle return value and or by
    application semantics.
  * Provide base-frequency configuration option in performance tab
    of preferences dialog. This configuration switch modifies the
    base synchronization rate of threads. By default 125, 250 and
    1000 Hz is provided. Note by using smaller buffer-size you might
    have to increase the base-frequency.
  * Implemented sticky controls, allowing you modify controls of
    grouped channels in one step.
  * Minor fixes and improvements.
  * Removed AgsMidiFileWriter and AgsMidiFileReader, please use
    AgsMidiBuilder or AgsMidiParser instead.
  * Added many prototypes of libags_server.so.1 and extended
    AgsServiceProvider interface.
  * Added AgsUiProvider interface.
- modified Source0 to point to new upstream directory
- added AGPL-3.0+ to license field since libags_server.so.1 uses it
- removed gsequencer.3-add-no-undefined.patch because applied
  upstream
- removed gsequencer.4-fix-test-arg.patch because applied upstream
- removed gsequencer.5-fix-turtle.patch because applied upstream
- provide gsequencer.3-fix-libgsequencer-doc.patch to fix missing
  types
- provide gsequencer.4-fix-return-value.patch to fix missing return
* Sun Sep 24 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.28
- removed gsequencer.3-fix-missing-return.patch because applied
  upstream
- enabled `make check` to run unit and functional tests
- provide gsequencer.3-add-no-undefined.patch to fix *_LDFLAGS and
  an issue with $(top_srcdir)
- provide gsequencer.4-fix-test-arg.patch to fix writing to
  excessed array index
- provide gsequencer.5-fix-turtle.patch to fix reading excessed
  array index
* Sat Sep 16 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.25
- moved fix gtk doc patch to gsequencer.2-fix-gtk-doc.patch
- provide patch gsequencer.3-fix-missing-return.patch
- modified gsequencer.spec to use macros to specify filenames
* Mon Aug 28 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.22
* Sun Aug 27 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.21
* Sun Aug 27 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.20
- updated gsequencer.3-fix-gtk-doc.patch
- removed gsequencer.4-fix-desktop-category.patch
- removed gsequencer.5-fix-missing-xml.patch
* Sat Aug 26 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.16
- updated gsequencer.4-fix-desktop-category.patch because upstream
  changed icon
- updated gsequencer.2-fix-license-and-logo.patch because upstream
  refactoring callback providing in view of providing a popup menu
- updated gsequencer.3-fix-gtk-doc.patch because upstream improved
  the makefile target
- removed gsequencer.5-fix-missing-include.patch because applied
  upstream
- provide patch gsequencer.5-disable-missing-xml.patch
* Tue Aug 22 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.14
- provide patch gsequencer.5-fix-missing-include.patch
* Tue Aug 22 2017 jkraehemann@gmail.com
- new upstream package containing bug-fixes and pulseaudio support
* Sat Aug  5 2017 jkraehemann@gmail.com
- initial upstream package
- provide patch gsequencer.0-fix-docbook-path.patch
- provide patch gsequencer.1-fix-libgsequencer-blue-print.patch
- provide patch gsequencer.3-fix-license-and-logo.patch
- provide patch gsequencer.4-fix-desktop-category.patch
